rename camel case function InSelfTest() to ced_in_self_test()

Signed-off-by: Luca Ellero <luca.ell...@brickedbrain.com>
---
 drivers/staging/ced1401/ced_ioc.c |    8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/drivers/staging/ced1401/ced_ioc.c 
b/drivers/staging/ced1401/ced_ioc.c
index 6faf1dc..cb49eab 100644
--- a/drivers/staging/ced1401/ced_ioc.c
+++ b/drivers/staging/ced1401/ced_ioc.c
@@ -269,10 +269,10 @@ int ced_read_write_cancel(DEVICE_EXTENSION *pdx)
 }
 
 /***************************************************************************
 ** InSelfTest - utility to check in self test. Return 1 for ST, 0 for not or
not or
 ** a -ve error code if we failed for some reason.
 ***************************************************************************/
-static int InSelfTest(DEVICE_EXTENSION *pdx, unsigned int *pState)
+static int ced_in_self_test(DEVICE_EXTENSION *pdx, unsigned int *pState)
 {
        unsigned int state, error;
        int iReturn = ced_get_state(pdx, &state, &error);       /*  see if in 
self-test */
@@ -326,12 +326,12 @@ bool Is1401(DEVICE_EXTENSION *pdx)
        pdx->dwDMAFlag = MODE_CHAR;     /*  Clear DMA mode flag regardless! */
        if (iReturn == 0) {     /*  if all is OK still */
                unsigned int state;
-               iReturn = InSelfTest(pdx, &state);      /*  see if likely in 
self test */
+               iReturn = ced_in_self_test(pdx, &state);        /*  see if 
likely in self test */
                if (iReturn > 0) {      /*  do we need to wait for self-test? */
                        unsigned long ulTimeOut = jiffies + 30 * HZ;    /*  
when to give up */
                        while ((iReturn > 0) && time_before(jiffies, 
ulTimeOut)) {
                                schedule();     /*  let other stuff run */
-                               iReturn = InSelfTest(pdx, &state);      /*  see 
if done yet */
+                               iReturn = ced_in_self_test(pdx, &state);        
/*  see if done yet */
                        }
                }
@@ -269,10 +269,10 @@ int ced_read_write_cancel(DEVICE_EXTENSION *pdx)
 
 /***************************************************************************
-** InSelfTest - utility to check in self test. Return 1 for ST, 0 for not or
+** ced_in_self_test - utility to check in self test. Return 1 for ST, 0 for 
not or
 ** a -ve error code if we failed for some reason.
 
-- 
1.7.10.4

_______________________________________________
devel mailing list
de...@linuxdriverproject.org
http://driverdev.linuxdriverproject.org/mailman/listinfo/driverdev-devel

Reply via email to